==> s3-1.7.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/s3/ReplaceKey.java <==
package software.amazon.awscdk.services.s3;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.16.0 (build 98909b5)", date = "2019-09-06T01:04:00.046Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.s3.$Module.class, fqn = "@aws-cdk/aws-s3.ReplaceKey")
public class ReplaceKey extends software.amazon.jsii.JsiiObject {

    protected ReplaceKey(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ReplaceKey(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * The object key prefix to use in the redirect request.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.s3.ReplaceKey prefixWith(final java.lang.String keyReplacement) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.s3.ReplaceKey.class, "prefixWith", software.amazon.awscdk.services.s3.ReplaceKey.class, new Object[] { java.util.Objects.requireNonNull(keyReplacement, "keyReplacement is required") });
    }

    /**
     * The specific object key to use in the redirect request.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.s3.ReplaceKey with(final java.lang.String keyReplacement) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.s3.ReplaceKey.class, "with", software.amazon.awscdk.services.s3.ReplaceKey.class, new Object[] { java.util.Objects.requireNonNull(keyReplacement, "keyReplacement is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getPrefixWithKey() {
        return this.jsiiGet("prefixWithKey", java.lang.String.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getWithKey() {
        return this.jsiiGet("withKey", java.lang.String.class);
    }
}

==> s3-1.9.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/s3/ReplaceKey.java <==
package software.amazon.awscdk.services.s3;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.17.0 (build 7d5d104)", date = "2019-09-20T09:56:05.223Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.s3.$Module.class, fqn = "@aws-cdk/aws-s3.ReplaceKey")
public class ReplaceKey extends software.amazon.jsii.JsiiObject {

    protected ReplaceKey(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ReplaceKey(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * The object key prefix to use in the redirect request.
     * 
     * @param keyReplacement This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.s3.ReplaceKey prefixWith(final java.lang.String keyReplacement) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.s3.ReplaceKey.class, "prefixWith", software.amazon.awscdk.services.s3.ReplaceKey.class, new Object[] { java.util.Objects.requireNonNull(keyReplacement, "keyReplacement is required") });
    }

    /**
     * The specific object key to use in the redirect request.
     * 
     * @param keyReplacement This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.s3.ReplaceKey with(final java.lang.String keyReplacement) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.s3.ReplaceKey.class, "with", software.amazon.awscdk.services.s3.ReplaceKey.class, new Object[] { java.util.Objects.requireNonNull(keyReplacement, "keyReplacement is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getPrefixWithKey() {
        return this.jsiiGet("prefixWithKey", java.lang.String.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getWithKey() {
        return this.jsiiGet("withKey", java.lang.String.class);
    }
}
